@@ -69,7 +69,7 @@ main (int argc, char *argv[])
 
 FILE *source;
 char *line;
-char content [10000];
+char content [PROC_DEV_SIZE];
 double filesize;
 int dormant;
 int scale;
@@ -130,14 +130,12 @@ while (1)
 	}
 
     fread (content,1,PROC_DEV_SIZE,source);
-
+    content[PROC_DEV_SIZE-1] = 0; /* Add null terminator */
 
 
     if ((line = strstr (content,mask)) == NULL)
       {
 	fprintf (stderr,"Device \"%s\" not found\n",argv[1]);
-	fprintf (stderr,"content = %s\n",content);
-	fprintf (stderr,"filesize =  %d\n",filesize);
 	endwin ();
 	exit (1);
       } 
@@ -185,7 +183,7 @@ int load_level;
     wprintw (INFO,"ERRORS\t  DROP\tFIFO");    
     wmove (INFO,3,1);
 
-    wprintw (INFO,"REC\t%Ld",rbytes);
+    wprintw (INFO,"RECV\t%Ld",rbytes);
     wmove (INFO,3,27);
     wprintw (INFO,"%Ld\t  %Ld\t  %Ld",rerrors,rdrop,rfifo);
     wmove (INFO,4,1);
